==> manydhcp2.5.2.tar.bz2: manydhcp/house/edit.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['house-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_POST['house_id'])) {puterror($result2['skin'],$TEXT['error-house5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['house_id'])>5) {puterror($result2['skin'],$TEXT['error-house6']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_POST['house'])) {puterror($result2['skin'],$TEXT['error-house1']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['house'])>255) {puterror($result2['skin'],$TEXT['error-house2']); require_once "../utils/bottom_adm.php"; exit();}

  if(isset($_POST['house'])) $house=trim($_POST['house']);
    else $house="";
     if(empty($house)) {puterror($result2['skin'],$TEXT['error-house3']); require_once "../utils/bottom_adm.php"; exit();}

  $_POST['house'] = rep($_POST['house']);
  $_POST['house_id'] = rep($_POST['house_id']);

  $query9 = "SELECT `house` FROM `tbl_house` WHERE `house`='".$_POST['house']."' ";
     $result9 = mysql_query($query9);
     if(!$result9) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
       if(mysql_num_rows($result9)>0) {puterror($result2['skin'],$TEXT['error-double']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $query10 = "SELECT `house` FROM `tbl_house` WHERE `house_id`='".$_POST['house_id']."' ";
  $result10 = mysql_query($query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
      $result_dom = mysql_fetch_array($result10);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-house3'];
  $what = $result_dom['house'].$TEXT['log-na'].$_POST['house'].$TEXT['log-id'].$_POST['house_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_house` SET `house` = '".$_POST['house']."' WHERE `house_id`='".$_POST['house_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-house8']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/house/edit.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['house-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_POST['house_id'])) {puterror($result2['skin'],$TEXT['error-house5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['house_id'])>5) {puterror($result2['skin'],$TEXT['error-house6']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_POST['house'])) {puterror($result2['skin'],$TEXT['error-house1']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_POST['house'])>255) {puterror($result2['skin'],$TEXT['error-house2']); require_once "../utils/bottom_adm.php"; exit();}

  if(isset($_POST['house'])) {$house=trim($_POST['house']);}
    else {$house="";}
     if(empty($house)) {puterror($result2['skin'],$TEXT['error-house3']); require_once "../utils/bottom_adm.php"; exit();}

  $_POST['house'] = rep($_POST['house']);
  $_POST['house_id'] = rep($_POST['house_id']);

  $query9 = "SELECT `house` FROM `tbl_house` WHERE `house`='".$_POST['house']."' ";
     $result9 = mysqli_query($dbcnx,$query9);
     if(!$result9) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
       if(mysqli_num_rows($result9)>0) {puterror($result2['skin'],$TEXT['error-double']); require_once "../utils/bottom_adm.php"; exit();}

  //*************************************
  //Информация для лога
  $query10 = "SELECT `house` FROM `tbl_house` WHERE `house_id`='".$_POST['house_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
      $result_dom = mysqli_fetch_array($result10,MYSQLI_ASSOC);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-house3'];
  $what = $result_dom['house'].$TEXT['log-na'].$_POST['house'].$TEXT['log-id'].$_POST['house_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "UPDATE `tbl_house` SET `house` = '".$_POST['house']."' WHERE `house_id`='".$_POST['house_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-house8']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>
